<?php
/**
 * Plugin Name: Elegant Catalogs for WooCommerce
 * Plugin URI: https://elegantmodules.com/elegant-catalogs-woocommerce-pdf-catalogs/
 * Description: Connect WooCommerce to Elegant Catalogs Catalog Builder.
 * Version: 1.0.0
 * Author: Elegant Modules
 * Author URI: https://elegantmodules.com
 * Text Domain: elegant-catalogs
 * Domain Path: /languages/
 *
 * License: GPL-2.0+
 * License URI: http://www.opensource.org/licenses/gpl-license.php
 */

/*
	Copyright 2021  Elegant Modules (hey@elegantmodules.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 2, as
	published by the Free Software Foundation.

	Permission is hereby granted, free of charge, to any person obtaining a copy of this
	software and associated documentation files (the "Software"), to deal in the Software
	without restriction, including without limitation the rights to use, copy, modify, merge,
	publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
	to whom the Software is furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or
	substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
	THE SOFTWARE.
*/

namespace ElegantModules\ElegantCatalogs;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'ElegantCatalogs' ) ) :

class ElegantCatalogs {

	private static $instance;

	public static function instance() {

		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof ElegantCatalogs ) ) {
			
			self::$instance = new ElegantCatalogs;

			self::$instance->constants();
			self::$instance->includes();
			self::$instance->hooks();
		}

		return self::$instance;
	}

	public function constants() {

		// Plugin version
		if ( ! defined( 'ELEGANT_CATALOGS_ORIGIN_URL' ) ) {
			define( 'ELEGANT_CATALOGS_ORIGIN_URL', 'https://elegantmodules.com' );
		}

		// Plugin version
		if ( ! defined( 'ELEGANT_CATALOGS_VERSION' ) ) {
			define( 'ELEGANT_CATALOGS_VERSION', '1.0.0' );
		}

		// Plugin file
		if ( ! defined( 'ELEGANT_CATALOGS_PLUGIN_FILE' ) ) {
			define( 'ELEGANT_CATALOGS_PLUGIN_FILE', __FILE__ );
		}

		// Plugin basename
		if ( ! defined( 'ELEGANT_CATALOGS_PLUGIN_BASENAME' ) ) {
			define( 'ELEGANT_CATALOGS_PLUGIN_BASENAME', plugin_basename( ELEGANT_CATALOGS_PLUGIN_FILE ) );
		}

		// Plugin directory path
		if ( ! defined( 'ELEGANT_CATALOGS_PLUGIN_DIR_PATH' ) ) {
			define( 'ELEGANT_CATALOGS_PLUGIN_DIR_PATH', trailingslashit( plugin_dir_path( ELEGANT_CATALOGS_PLUGIN_FILE )  ) );
		}

		// Plugin directory URL
		if ( ! defined( 'ELEGANT_CATALOGS_PLUGIN_DIR_URL' ) ) {
			define( 'ELEGANT_CATALOGS_PLUGIN_DIR_URL', trailingslashit( plugin_dir_url( ELEGANT_CATALOGS_PLUGIN_FILE )  ) );
		}

		// Templates directory
		if ( ! defined( 'ELEGANT_CATALOGS_PLUGIN_TEMPLATES_DIR_PATH' ) ) {
			define ( 'ELEGANT_CATALOGS_PLUGIN_TEMPLATES_DIR_PATH', ELEGANT_CATALOGS_PLUGIN_DIR_PATH . 'templates/' );
		}
	}

	public function includes() {

		// Controllers
		foreach ( (array) glob( __DIR__ . '/includes/Controllers/*.php' ) as $file ) {
			$file_parts = explode( '/', $file );
			$filename = array_pop( $file_parts );
			$class_name = str_replace( '.php', '', $filename );
			$class = "ElegantModules\\ElegantCatalogs\\Controllers\\{$class_name}";
			include_once $file;
			new $class;
		}
	}

	public function hooks() {
		register_activation_hook( ELEGANT_CATALOGS_PLUGIN_FILE, array( $this, 'activate' ) );
		add_action( 'plugins_loaded', array( $this, 'loaded' ) );
		add_filter( 'plugin_action_links_' . ELEGANT_CATALOGS_PLUGIN_BASENAME, array( $this, 'action_links' ) );
	}

	public function loaded() {

		$locale = is_admin() && function_exists( 'get_user_locale' ) ? get_user_locale() : get_locale();
		$locale = apply_filters( 'plugin_locale', $locale, 'elegant-catalogs' );
		
		unload_textdomain( 'elegant-catalogs' );
		
		load_textdomain( 'elegant-catalogs', WP_LANG_DIR . '/elegant-catalogs/elegant-catalogs-' . $locale . '.mo' );
		load_plugin_textdomain( 'elegant-catalogs', false, dirname( ELEGANT_CATALOGS_PLUGIN_BASENAME ) . '/languages' );
	}

	public function action_links( $links ) {
		if ( ! self::is_store_connected() ) {
			$links[] = sprintf( '<a href="%s" aria-label="%s">%s</a>', admin_url( 'admin.php?page=elegant-catalogs' ), __( 'Connect Your Store', 'elegant-catalogs' ), __( 'Connect Your Store', 'elegant-catalogs' ) );
		}
		return $links;
	}

	public static function template( $file, $vars ) {
		extract( $vars );
		include ELEGANT_CATALOGS_PLUGIN_TEMPLATES_DIR_PATH . untrailingslashit( $file ) . '.php';
	}

	public static function is_store_connected() {
		return ! empty( get_option( 'elegant_catalogs_site_connected', '' ) );
	}
}

endif;

/**
 * Main function
 * 
 * @return object 	ElegantCatalogs instance
 */
function elegant_catalogs() {
	return ElegantCatalogs::instance();
}

add_action( 'plugins_loaded', __NAMESPACE__ . '\\elegant_catalogs_init' );
/**
 * Initialize the plugin.
 *
 * @return void
 */
function elegant_catalogs_init() {
	elegant_catalogs();
}
