<?php

/**
 *	Modifies REST API endpoints as needed to support the Elegant Catalogs Catalog Builder.
 *
 *	@package Elegant Catalogs
 */

namespace ElegantModules\ElegantCatalogs\Controllers;
use \ElegantModules\ElegantCatalogs\ElegantCatalogs as ElegantCatalogs;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class RESTCtrl {

	public function __construct() {
		add_filter( 'rest_product_collection_params', array( $this, 'wc_products_rest_api_query_all' ) );
		add_filter( 'woocommerce_rest_prepare_product_object', array( $this, 'wc_rest_api_add_custom_data_to_product' ) );
	}

	/**
	 * Modify the WooCommerce ($_GET) Products API query to allow for querying all products.
	 *
	 * @param 	array 	$query_params 	Default query params
	 *
	 * @return 	array
	 */
	public function wc_products_rest_api_query_all( $query_params ) {
		// Check for our custom request param
		if ( ! empty( $_REQUEST['product_catalog'] ) && 'all' === $_REQUEST['product_catalog'] ) {
			// Allow for returning all products (sets the posts_per_page to -1)
			$query_params['per_page']['minimum'] = -1;
			$query_params['per_page']['sanitize_callback'] = 'sanitize_text_field';
		}
	    return $query_params;
	}

	/**
	 * Add custom data to the product response.
	 *
	 * @param 	object	$response	REST_Response
	 *
	 * @return object
	 */
	public function wc_rest_api_add_custom_data_to_product( $response ) {

		$product_id = (int) $response->data['id'];
		
		// Add the featured product image
		$response->data['thumbnail'] = get_the_post_thumbnail_url( $product_id );

		// Add a custom description for the product in a catalog
		$catalog_description = get_post_meta( $product_id, 'ec_catalog_description', true );
		if ( ! empty( $catalog_description ) ) {
			$response->data['catalog_description'] = apply_filters( 'the_content', $catalog_description );
		}

		return $response;
	}
}
